@@ -374,6 +374,12 @@ export const TaskTemplateDesignation = yup.object().shape({
   designationId: yup.string().required(),
 });
 
+export const ProcedureTypeSurvey = yup.object().shape({
+  // id is auto generated by db, so don't require it on import
+  procedureTypeId: yup.string().required(),
+  surveyId: yup.string().required(),
+});
+
 export const ReferenceMedicationTemplate = yup
   .object()
   .shape({
