@@ -12,6 +12,7 @@ import { SERVER_TYPES } from '@tamanu/constants';
 import { buildRoutes } from './buildRoutes';
 import { authModule } from './auth';
 import { publicRoutes } from './publicRoutes';
+import { patientPortalModule } from './patientPortal/patientPortalRoutes';
 
 import { defaultErrorHandler } from './middleware/errorHandler';
 import { loadshedder } from './middleware/loadshedder';
@@ -113,6 +114,12 @@ export async function createApi(ctx) {
     });
   });
 
+  // Patient Portal - must go before main API to avoid main authentication
+  express.use('/api/portal', async (req, res, next) => {
+    const patientPortalEnabled = await req.settings.get('features.patientPortal');
+    return patientPortalEnabled ? patientPortalModule(req, res, next) : res.status(501).end();
+  });
+
   // API
   express.use('/api', api(ctx));
 
