@@ -1,3 +1,4 @@
+import config from 'config';
 import { defineDbNotifier } from '@tamanu/shared/services/dbNotifier';
 import { NOTIFY_CHANNELS } from '@tamanu/constants';
 
@@ -15,12 +16,15 @@ export async function createApp(ctx) {
     NOTIFY_CHANNELS.TABLE_CHANGED,
   ]);
   await registerSyncLookupUpdateListener(ctx.store.models, dbNotifier);
-  const websocket = await createWebsocket(api.httpServer, ctx);
+
+  if (config["socket.io"].enabled) {
+    await createWebsocket(api.httpServer, ctx);
+  }
 
   // Release the connection back to the pool when the server is closed
   api.httpServer.on('close', () => {
     dbNotifier.close();
   });
 
-  return { express: api.express, server: api.httpServer, websocket };
+  return { express: api.express, server: api.httpServer };
 }
