@@ -10,7 +10,12 @@ export const generateCertificate = async ({ patientId }) => {
   try {
     const patient = await Patient.findByPk(patientId);
     log.info(`Generating vaccine certificate for patient id "${patientId}"`);
-    const pdf = await makeVaccineCertificate(patient, 'Admin', null, store.models);
+    const pdf = await makeVaccineCertificate({
+      patient,
+      printedBy: 'Admin',
+      printedDate: null,
+      models: store.models,
+    });
     log.info(`Certificate output: `, pdf);
   } catch (error) {
     process.stderr.write(`Report failed: ${error.stack}\n`);
