@@ -21,7 +21,7 @@ export function getLatestVersion(versions, status) {
 
 export async function verifyQuery(query, paramDefinitions = [], store, verbose) {
   try {
-    const replacements = await getReportQueryReplacements(store, paramDefinitions);
+    const replacements = await getReportQueryReplacements(paramDefinitions);
 
     // use EXPLAIN instead of PREPARE because we don't want to stuff around deallocating the statement
     const results = await store.sequelize.query(`EXPLAIN ${query}`, {
