@@ -2,9 +2,9 @@ import React from 'react';
 import { Box, Logo } from './Layout';
 import { H1, H2 } from './Typography';
 
-export const CovidLetterheadSection = ({ getLocalisation, logoSrc }) => {
-  const title = getLocalisation('templates.letterhead.title');
-  const subTitle = getLocalisation('templates.letterhead.subTitle');
+export const CovidLetterheadSection = ({ getSetting, logoSrc }) => {
+  // TODO: maybe make this the same as LetterheadSection for consistency
+  const { title, subTitle } = getSetting('templates.letterhead');
   return (
     <>
       {logoSrc && <Logo logoSrc={logoSrc} />}
